==> pointpos_api-0.0.13.tar.gz: lib/api/item_category_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/item_category.dart';

part 'item_category_api.jretro.dart';

@GenApiClient()
class ItemCategoryApi extends ApiClient with _$ItemCategoryApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    ItemCategoryApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Itemcategory
    ///
    /// Create Itemcategory
    @PostReq(path: "/item-category", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<ItemCategory> createItemcategory(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() ItemCategory body
        ) {
        return super.createItemcategory(
        
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Itemcategory By ID
    ///
    /// Delete Itemcategory By ID
    @DeleteReq(path: "/item-category/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteItemcategoryByID(
            @PathParam("id") num id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.deleteItemcategoryByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Get Itemcategory List
    ///
    /// Get Itemcategory  List
    @GetReq(path: "/item-category", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<ItemCategory>> findItemcategory(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findItemcategory(
        
        authorization, 
        
        xAPIKey
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Itemcategory By ID
    ///
    /// Get Itemcategory By ID
    @GetReq(path: "/item-category/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<ItemCategory> getItemcategoryByID(
            @PathParam("id") num id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.getItemcategoryByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Update Itemcategory By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/item-category/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<ItemCategory> updateItemcategoryByID(
            @PathParam("id") num id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() ItemCategory body
        ) {
        return super.updateItemcategoryByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }


}

==> pointpos_api-0.0.16.tar.gz: lib/api/item_category_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/item_category.dart';

part 'item_category_api.jretro.dart';

@GenApiClient()
class ItemCategoryApi extends ApiClient with _$ItemCategoryApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    ItemCategoryApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Itemcategory
    ///
    /// Create Itemcategory
    @PostReq(path: "/item-category", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<ItemCategory> createItemcategory(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() ItemCategory body
        ) {
        return super.createItemcategory(
        
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Itemcategory By ID
    ///
    /// Delete Itemcategory By ID
    @DeleteReq(path: "/item-category/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteItemcategoryByID(
            @PathParam("id") num id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.deleteItemcategoryByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Get Itemcategory List
    ///
    /// Get Itemcategory  List
    @GetReq(path: "/item-category", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<ItemCategory>> findItemcategory(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findItemcategory(
        
        authorization, 
        
        xAPIKey, 
        
        xPin
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Itemcategory By ID
    ///
    /// Get Itemcategory By ID
    @GetReq(path: "/item-category/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<ItemCategory> getItemcategoryByID(
            @PathParam("id") num id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.getItemcategoryByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Update Itemcategory By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/item-category/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<ItemCategory> updateItemcategoryByID(
            @PathParam("id") num id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() ItemCategory body
        ) {
        return super.updateItemcategoryByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }


}
